#include "HX711.h"

#define calibration_factor 1340.0 //makes the load sensor measure in grams

#define LOADCELL_DOUT_PIN  3
#define LOADCELL_SCK_PIN  2

float multiplicity_factor = 0.1963; //percentage of dust that is sucked through the vacuum
float flow_rate = 2000; //mass flow rate of malt (in kg/hr)
float run_time = 2; //vacuum run-time in one cycle (in seconds)
float off_time = 6; //time between vacuum run-times (in seconds)
float composition; //dust composition in malt flow stream (mass/mass %)

HX711 scale;

void setup() {
  pinMode(LED_BUILTIN, OUTPUT); //initialize the Arduino-relay connection
  Serial.begin(9600);
  scale.begin(LOADCELL_DOUT_PIN, LOADCELL_SCK_PIN);
  scale.set_scale(calibration_factor);
  scale.tare(); //set scale to 0
}

void loop() {
  digitalWrite(LED_BUILTIN, LOW); //turns fan on
  delay(run_time * 1000); //fan stays on for run_time
  digitalWrite(LED_BUILTIN, HIGH); //turns fan off
  delay(off_time * 1000); //fan stays off for off_time
  composition = ((scale.get_units(), 2) / multiplicity_factor) / (flow_rate * (1/36) * run_time); //calculate dust composition
  Serial.print("Dust Composition is: ");
  Serial.print(composition * 100); 
  Serial.println("%");
  scale.tare(); //set scale to 0
}
